#!/bin/bash
# usage:
# veto_separation.sh catalog.csv sep_threshold_arcsec faint_mag_thr mag_diff_threshold 
# input catalog must have at least the folowing columns in this order:
# id_column 
# RA_column 
# Dec_column
# mag_coloumn

mydir=`dirname $0`
# find the column names for the different columns

col_name_id=`head -n1 $1 | tr , \\\n | head -n1 | tail -n 1`
col_name_RA=`head -n1 $1 | tr , \\\n | head -n2 | tail -n 1`
col_name_Dec=`head -n1 $1 | tr , \\\n | head -n3 | tail -n 1`
col_name_mag=`head -n1 $1 | tr , \\\n | head -n4 | tail -n 1`

# input parameters: separation threshold (arcsec) , magnitude limit (faintest) (mL) , magnitude difference limit (dm)
# stars are rejected if their mag (m) is above the magnitude limit (mL) or if there is a star within the given 
# angular separation which is brighter than m+dm   

sep_thr=$2
mag_faint_thr=$3
mag_diff_thr=$4

# match catalog against itself with the user-specified angular separation threshold

outfile="$5" 

java -jar ${mydir}/stilts.jar tmatch2 ifmt1=csv ifmt2=csv in1="$1" in2="$1" ofmt=csv \
out="$outfile" matcher="sky" values1="\$2 \$3" values2="\$2 \$3" params="$sep_thr" \
join="1and2" find="all" \
ocmd="select (!equals(${col_name_id}_1,${col_name_id}_2));select (${col_name_mag}_1>$mag_faint_thr||(${col_name_mag}_2-${col_name_mag}_1>$mag_diff_thr));sort \$1\ separation;uniq;keepcols \$1\ \$2\ \$3\ \$4\ separation"

#ocmd explained:
# first, filter out those rows where a star was matched against itself (separation is 0 of course)
# then, select those rows where the first star is fainter than our limit or the 
#       second star with the separation threshold is not much fainter 
# next, sort the remaining, vetoed stars by ID and separation, highest first
# next, make a uniq list of stars by eliminating dups, keeping the entry with the smallest separation  
# finally drop most columns and keep only the frist 4, plus the separation column
